smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel

# ``smartcard`.`wx`.`CardAndReaderTreePanel`.`CardAndReaderTreePanel``

class documentation

`class CardAndReaderTreePanel(wx.Panel):`

View In Hierarchy

Panel containing the smart card and reader tree controls.

Method | `__init__` | Constructor. Create a smartcard and reader tree control on the left-hand side of the application main frame.
Method | `OnDestroy` | Called on panel destruction.
Instance Variable | `cardmonitor` | Undocumented
Instance Variable | `cardtreecardobserver` | Undocumented
Instance Variable | `cardtreectrl` | Undocumented
Instance Variable | `readermonitor` | Undocumented
Instance Variable | `readertreecardobserver` | Undocumented
Instance Variable | `readertreectrl` | Undocumented
Instance Variable | `readertreereaderobserver` | Undocumented
Class | `_CardObserver` | Inner CardObserver. Gets notified of card insertion removal by the CardMonitor.
Class | `_ReaderObserver` | Inner ReaderObserver. Gets notified of reader insertion/removal by the ReaderMonitor.

def __init__(self, parent, appstyle, clientpanel):

Constructor. Create a smartcard and reader tree control on the left-hand side of the application main frame.

Parameters
parent | the tree panel parent
appstyle | a combination of the following styles (bitwise or |) TR_SMARTCARD: display a smartcard tree panel TR_READER: display a reader tree panel default is TR_DEFAULT = TR_SMARTCARD
clientpanel | the client panel to notify of smartcard and reader events

def OnDestroy(self, event):

Called on panel destruction.

cardmonitor =

Undocumented

cardtreecardobserver =

Undocumented

cardtreectrl =

Undocumented

readermonitor =

Undocumented

readertreecardobserver =

Undocumented

readertreectrl =

Undocumented

readertreereaderobserver =

Undocumented